/*
	      VMA Editor - HeightField Primitive Handling
 */

#ifndef EDITORHF_H
#define EDITORHF_H

#include <sys/types.h>

#include "v3dmodel.h"
#include "editor.h"


extern void EditorHFPrimitiveRealize(
	ma_editor_struct *editor,
	mp_heightfield_load_struct *mp_heightfield_load,
	gbool rerealize
);
extern void EditorHFPrimitiveUnrealize(
	ma_editor_struct *editor,
	mp_heightfield_load_struct *mp_heightfield_load
);

extern void EditorHFDialogMap(
	ma_editor_struct *editor,
	void *p         /* If NULL, then implies create. */
);
extern void EditorHFDialogBrowseCB(GtkWidget *widget, gpointer data);
extern void EditorHFDialogOKCB(void *idialog, void *data);
extern void EditorHFDialogApplyCB(void *idialog, void *data);
extern void EditorHFDialogCancelCB(void *idialog, void *data);


#endif	/* EDITORHF_H */
